from setuptools import setup

setup(
    name="analyticsTestNN1",
    version="1.0.0",
    description="Testing out the analytics package",
    author="Testing@testing",
    license="MIT",
    packages=["analyticsTestNN1"],
    install_requires=["pandas"],
)